@@ -105,13 +105,13 @@ print.summary.LF <- function(x, digits = max(3, getOption("digits") - 3), ...){
 }
 
 #############################################
-########## Methods for class ITE ############
+########## Methods for class CATE ############
 #############################################
 
-#' Confidence Intervals for Bias-corrected ITE Estimators
+#' Confidence Intervals for Bias-corrected CATE Estimators
 #' @description Computes confidence intervals for bias-corrected estimators; Each
 #' row corresponds to a loading.
-#' @param object An object of class `ITE`, a result of a call to `ITE`
+#' @param object An object of class `CATE`, a result of a call to `CATE`
 #' @param probability Whether returns CI with probability transformation or not (default=\code{FALSE})
 #' @param alpha Level of significance to construct confidence interval (default=0.05)
 #' @param alternative Indicates the alternative hypothesis to construct confidence interval and must be one of "two.sided" (default), "less", or "greater".
@@ -122,11 +122,11 @@ print.summary.LF <- function(x, digits = max(3, getOption("digits") - 3), ...){
 #' @export
 #' @examples
 #' \dontrun{
-#' ##-- Continuing the ITE(.) example:
+#' ##-- Continuing the CATE(.) example:
 #' out = ci(Est)
 #' out
 #' }
-ci.ITE <- function(object, probability=FALSE, alpha=0.05, alternative=c("two.sided","less","greater"), ...){
+ci.CATE <- function(object, probability=FALSE, alpha=0.05, alternative=c("two.sided","less","greater"), ...){
   alternative = match.arg(alternative)
 
   if(probability==FALSE){
@@ -162,11 +162,11 @@ ci.ITE <- function(object, probability=FALSE, alpha=0.05, alternative=c("two.sid
   return(output.ci)
 }
 
-#' Summarizing ITE
-#' @description `summary` method for class `ITE`
-#' @param object An object of class `ITE`, a result of a call to `ITE`
+#' Summarizing CATE
+#' @description `summary` method for class `CATE`
+#' @param object An object of class `CATE`, a result of a call to `CATE`
 #' @param ... arguments to pass down
-#' @return The function `summary.ITE` computes and returns a list of summary statistics.
+#' @return The function `summary.CATE` computes and returns a list of summary statistics.
 #' \item{output.est}{a \eqn{ncol(loading.mat)} x 7 matrix with columns for the loading,
 #' plugin(biased) estimators, bias-corrected estimators, its standard error, z-statistic,
 #' corresponding (two-sided) p-value and significance stars; Each row corresponds to each loading.}
@@ -174,11 +174,11 @@ ci.ITE <- function(object, probability=FALSE, alpha=0.05, alternative=c("two.sid
 #' @export
 #' @examples
 #' \dontrun{
-#' ##-- Continuing the ITE(.) example:
+#' ##-- Continuing the CATE(.) example:
 #' sEst = summary(Est)
 #' sEst
 #' }
-summary.ITE <- function(object, ...){
+summary.CATE <- function(object, ...){
   est.plugin.vec = object$est.plugin.vec
   est.debias.vec = object$est.debias.vec
   se.vec         = object$se.vec
@@ -192,23 +192,23 @@ summary.ITE <- function(object, ...){
   output.est[,7] = stars.pval(output.est[,6])
 
   x = list(output.est = output.est)
-  class(x) = "summary.ITE"
+  class(x) = "summary.CATE"
   x
 }
 
-#' Printing Summarizing ITE
-#' @description `print` method for class `summary.ITE`
-#' @param x An object of class `summary.ITE`, a result of a call to `summary.ITE`
+#' Printing Summarizing CATE
+#' @description `print` method for class `summary.CATE`
+#' @param x An object of class `summary.CATE`, a result of a call to `summary.CATE`
 #' @param digits The number of digits to use when printing
 #' @param ... arguments to pass down
 #' @keywords internal
 #' @export
 #' @examples
 #' \dontrun{
-#' #' ##-- Continuing the ITE(.) example:
+#' #' ##-- Continuing the CATE(.) example:
 #' summary(Est)
 #' }
-print.summary.ITE <- function(x, digits = max(3, getOption("digits") - 3), ...){
+print.summary.CATE <- function(x, digits = max(3, getOption("digits") - 3), ...){
   output.est = x$output.est
   cat("Call: \nInference for Treatment Effect\n\n")
   cat("Estimators: \n")
@@ -316,3 +316,199 @@ print.summary.QF <- function(x, digits = max(3, getOption("digits") - 3), ...){
   print(output.est, digits=digits, quote=F, row.names=F)
   invisible(x)
 }
+
+############################################
+########## Methods for class InnProd ############
+############################################
+
+#' Confidence Intervals for Bias-corrected InnProd Estimators
+#' @description Computes confidence intervals for bias-corrected estimator
+#' @param object An object of class `InnProd`, a result of a call to `InnProd`
+#' @param alpha Level of significance to construct confidence interval (default=0.05)
+#' @param alternative Indicates the alternative hypothesis to construct confidence interval and must be one of "two.sided" (default), "less", or "greater".
+#' @param ... arguments to pass down
+#' @return A vector giving lower and upper confidence limits for bias-corrected
+#' estimator
+#' @keywords internal
+#' @export
+#' @examples
+#' \dontrun{
+#' ##-- Continuing the InnProd(.) example:
+#' out = ci(Est)
+#' out
+#' }
+ci.InnProd <- function(object, probability=FALSE, alpha=0.05, alternative=c("two.sided","less","greater"), ...){
+  if(probability==TRUE){
+    cat("InnProd only supports probability=FALSE \n")
+    probability=FALSE
+  }
+
+  alternative = match.arg(alternative)
+  est.debias = object$est.debias
+  se     = object$se
+  tau    = object$tau
+  n.tau = length(tau)
+  if(alternative=="two.sided"){
+    output.ci = cbind(est.debias - qnorm(1-alpha/2)*se, est.debias + qnorm(1-alpha/2)*se)
+  }else if(alternative=="less"){
+    output.ci = cbind(-Inf, est.debias + qnorm(1-alpha)*se)
+  }else if(alternative=="greater"){
+    output.ci = cbind(est.debias - qnorm(1-alpha)*se, Inf)
+  }
+  output.ci = data.frame(cbind(tau, output.ci))
+  colnames(output.ci) = c("tau","lower","upper")
+  return(output.ci)
+}
+
+#' Summarizing InnProd
+#' @description `summary` method for class `InnProd`
+#' @param object An object of class `InnProd`, a result of a call to `InnProd`
+#' @param ... arguments to pass down
+#' @return The function `summary.InnProd` computes and returns a list of summary statistics.
+#' \item{output.est}{A 6-dimensional vector with elements for plugin(biased) estimators, bias-corrected estimators, its standard error, z-statistic,
+#' corresponding (two-sided) p-value and significance stars}
+#' @keywords internal
+#' @export
+#' @examples
+#' \dontrun{
+#' ##-- Continuing the InnProd(.) example:
+#' sEst = summary(Est)
+#' sEst
+#' }
+summary.InnProd <- function(object, ...){
+  est.plugin = object$est.plugin
+  est.debias = object$est.debias
+  se = object$se
+  tau = object$tau
+
+  n.tau = length(tau)
+  output.est = data.frame(matrix(NA, nrow=n.tau, ncol=7))
+  colnames(output.est) = c("tau","est.plugin","est.debias","Std. Error","z value","Pr(>|z|)", "")
+  output.est[,1] = tau
+  output.est[,c(2,3,4)] = cbind(rep(est.plugin, n.tau), rep(est.debias, n.tau), se)
+  output.est[,5] = rep(est.debias, n.tau) / se
+  output.est[,6] = apply(cbind(pnorm(output.est[,5]), 1-pnorm(output.est[,5])), MARGIN = 1, FUN=min)*2
+  output.est[,7] = stars.pval(output.est[,6])
+
+  x = list(output.est = output.est)
+  class(x) = "summary.InnProd"
+  x
+}
+
+#' Printing summarizing InnProd
+#' @description `print` method for class `summary.InnProd`
+#' @param x An object of class `summary.InnProd`, a result of a call to `summary.InnProd`
+#' @param digits The number of digits to use when printing
+#' @param ... arguments to pass down
+#' @keywords internal
+#' @export
+#' @examples
+#' \dontrun{
+#' #' ##-- Continuing the InnProd(.) example:
+#' summary(Est)
+#' }
+print.summary.InnProd <- function(x, digits = max(3, getOption("digits") - 3), ...){
+  output.est = x$output.est
+
+  cat("Call: \nInference for Inner Product\n\n")
+  print(output.est, digits=digits, quote=F, row.names=F)
+  invisible(x)
+}
+
+############################################
+########## Methods for class Dist ############
+############################################
+
+#' Confidence Intervals for Bias-corrected Dist Estimators
+#' @description Computes confidence intervals for bias-corrected estimator
+#' @param object An object of class `Dist`, a result of a call to `Dist`
+#' @param alpha Level of significance to construct confidence interval (default=0.05)
+#' @param alternative Indicates the alternative hypothesis to construct confidence interval and must be one of "two.sided" (default), "less", or "greater".
+#' @param ... arguments to pass down
+#' @return A vector giving lower and upper confidence limits for bias-corrected
+#' estimator
+#' @keywords internal
+#' @export
+#' @examples
+#' \dontrun{
+#' ##-- Continuing the Dist(.) example:
+#' out = ci(Est)
+#' out
+#' }
+ci.Dist <- function(object, probability=FALSE, alpha=0.05, alternative=c("two.sided","less","greater"), ...){
+  if(probability==TRUE){
+    cat("QF only supports probability=FALSE \n")
+    probability=FALSE
+  }
+
+  alternative = match.arg(alternative)
+  est.debias = object$est.debias
+  se     = object$se
+  tau    = object$tau
+  n.tau = length(tau)
+  if(alternative=="two.sided"){
+    output.ci = cbind(est.debias - qnorm(1-alpha/2)*se, est.debias + qnorm(1-alpha/2)*se)
+  }else if(alternative=="less"){
+    output.ci = cbind(-Inf, est.debias + qnorm(1-alpha)*se)
+  }else if(alternative=="greater"){
+    output.ci = cbind(est.debias - qnorm(1-alpha)*se, Inf)
+  }
+  output.ci = data.frame(cbind(tau, output.ci))
+  colnames(output.ci) = c("tau","lower","upper")
+  return(output.ci)
+}
+
+#' Summarizing Dist
+#' @description `summary` method for class `Dist`
+#' @param object An object of class `Dist`, a result of a call to `Dist`
+#' @param ... arguments to pass down
+#' @return The function `summary.Dist` computes and returns a list of summary statistics.
+#' \item{output.est}{A 6-dimensional vector with elements for plugin(biased) estimators, bias-corrected estimators, its standard error, z-statistic,
+#' corresponding (two-sided) p-value and significance stars}
+#' @keywords internal
+#' @export
+#' @examples
+#' \dontrun{
+#' ##-- Continuing the Dist(.) example:
+#' sEst = summary(Est)
+#' sEst
+#' }
+summary.Dist <- function(object, ...){
+  est.plugin = object$est.plugin
+  est.debias = object$est.debias
+  se = object$se
+  tau = object$tau
+
+  n.tau = length(tau)
+  output.est = data.frame(matrix(NA, nrow=n.tau, ncol=7))
+  colnames(output.est) = c("tau","est.plugin","est.debias","Std. Error","z value","Pr(>|z|)", "")
+  output.est[,1] = tau
+  output.est[,c(2,3,4)] = cbind(rep(est.plugin, n.tau), rep(est.debias, n.tau), se)
+  output.est[,5] = rep(est.debias, n.tau) / se
+  output.est[,6] = apply(cbind(pnorm(output.est[,5]), 1-pnorm(output.est[,5])), MARGIN = 1, FUN=min)*2
+  output.est[,7] = stars.pval(output.est[,6])
+
+  x = list(output.est = output.est)
+  class(x) = "summary.Dist"
+  x
+}
+
+#' Printing summarizing Dist
+#' @description `print` method for class `summary.Dist`
+#' @param x An object of class `summary.Dist`, a result of a call to `summary.Dist`
+#' @param digits The number of digits to use when printing
+#' @param ... arguments to pass down
+#' @keywords internal
+#' @export
+#' @examples
+#' \dontrun{
+#' #' ##-- Continuing the Dist(.) example:
+#' summary(Est)
+#' }
+print.summary.Dist <- function(x, digits = max(3, getOption("digits") - 3), ...){
+  output.est = x$output.est
+
+  cat("Call: \nInference for Distance\n\n")
+  print(output.est, digits=digits, quote=F, row.names=F)
+  invisible(x)
+}
